==> xplr-0.14.6.tar.gz: xplr-0.14.6/docs/en/src/awesome-plugins.md <==
Awesome Plugins
===============

Here's a list of awesome xplr plugins that you might want to check out. If none
of the following plugins work for you, it's very easy to
[write your own][1].


Categories
----------

- [Extension][32]
- [Integration][2]
- [Theme][3]


Extension
---------

- [**type-to-nav.xplr**][28] Inspired by [nnn's type-to-nav mode][29] for xplr,
  with some tweaks.
- [**completion.xplr**][25] The missing tab completion for xplr input buffer.
- [**comex.xplr**][21] One xplr plugin to compress and extract them all.


Integration
-----------

- [**dragon.xplr**][4] Drag and drop files using [dragon][5].
- [**dua-cli.xplr**][6] Get the disk usage using [dua-cli][7] with selection
  support.
- [**fzf.xplr**][8] Fuzzy search using [fzf][9] to focus on a file or enter
  into a directory.
- [**paste-rs.xplr**][23] Use this plugin to paste your files to
  [paste.rs][24], and open/delete them later using [fzf][9].
- [**preview-tabbed.xplr**][10] Preview paths using suckless [tabbed][11] and
  [nnn preview-tabbed][12].
- [**qrcp.xplr**][26] Send and receive files via QR code using [qrcp][27].
- [**trash-cli.xplr**][13] Trash files and directories using [trash-cli][14].
- [**xargs.xplr**][22] Batch execute commands on the focused or selected files
  using `xargs`.
- [**xclip.xplr**][15] Copy and paste with system clipboard using [xclip][16].
- [**zoxide.xplr**][17] Change directory using the [zoxide][18] database.


Theme
-----

- [**material-landscape.xplr**][19] Material Landscape
- [**material-landscape2.xplr**][20] Material Landscape 2
- [**zentable.xplr**][31] A clean, distraction free xplr table UI
- [**icons.xplr**][30] An icon theme for xplr.


[1]:./writing-plugins.md
[2]:#integration
[3]:#theme
[4]:https://github.com/sayanarijit/dragon.xplr
[5]:https://github.com/mwh/dragon
[6]:https://github.com/sayanarijit/dua-cli.xplr
[7]:https://github.com/Byron/dua-cli
[8]:https://github.com/sayanarijit/fzf.xplr
[9]:https://github.com/junegunn/fzf
[10]:https://github.com/sayanarijit/preview-tabbed.xplr
[11]:https://tools.suckless.org/tabbed/
[12]:https://github.com/jarun/nnn/blob/master/plugins/preview-tabbed
[13]:https://github.com/sayanarijit/trash-cli.xplr
[14]:https://github.com/andreafrancia/trash-cli
[15]:https://github.com/sayanarijit/xclip.xplr
[16]:https://github.com/astrand/xclip
[17]:https://github.com/sayanarijit/zoxide.xplr
[18]:https://github.com/ajeetdsouza/zoxide
[19]:https://github.com/sayanarijit/material-landscape.xplr
[20]:https://github.com/sayanarijit/material-landscape2.xplr
[21]:https://github.com/sayanarijit/comex.xplr
[22]:https://github.com/sayanarijit/xargs.xplr
[23]:https://github.com/dtomvan/paste-rs.xplr
[24]:https://paste.rs
[25]:https://github.com/sayanarijit/completion.xplr
[26]:https://github.com/sayanarijit/qrcp.xplr
[27]:https://github.com/claudiodangelis/qrcp
[28]:https://github.com/prncss-xyz/type-to-nav.xplr
[29]:https://github.com/jarun/nnn/wiki/concepts#type-to-nav
[30]:https://github.com/prncss-xyz/icons.xplr
[31]:https://github.com/sayanarijit/zentable.xplr
[32]:#extension

==> xplr-0.14.7.tar.gz: xplr-0.14.7/docs/en/src/awesome-plugins.md <==
Awesome Plugins
===============

Here's a list of awesome xplr plugins that you might want to check out. If none
of the following plugins work for you, it's very easy to
[write your own][1].


Categories
----------

- [Extension][32]
- [Integration][2]
- [Theme][3]


Extension
---------

- [**type-to-nav.xplr**][28] Inspired by [nnn's type-to-nav mode][29] for xplr,
  with some tweaks.
- [**completion.xplr**][25] The missing tab completion for xplr input buffer.
- [**comex.xplr**][21] One xplr plugin to compress and extract them all.


Integration
-----------

- [**alacritty.xplr**][33] [Alacritty][34] integration for xplr.
- [**dragon.xplr**][4] Drag and drop files using [dragon][5].
- [**dua-cli.xplr**][6] Get the disk usage using [dua-cli][7] with selection
  support.
- [**fzf.xplr**][8] Fuzzy search using [fzf][9] to focus on a file or enter
  into a directory.
- [**paste-rs.xplr**][23] Use this plugin to paste your files to
  [paste.rs][24], and open/delete them later using [fzf][9].
- [**preview-tabbed.xplr**][10] Preview paths using suckless [tabbed][11] and
  [nnn preview-tabbed][12].
- [**qrcp.xplr**][26] Send and receive files via QR code using [qrcp][27].
- [**trash-cli.xplr**][13] Trash files and directories using [trash-cli][14].
- [**xargs.xplr**][22] Batch execute commands on the focused or selected files
  using `xargs`.
- [**xclip.xplr**][15] Copy and paste with system clipboard using [xclip][16].
- [**zoxide.xplr**][17] Change directory using the [zoxide][18] database.


Theme
-----

- [**material-landscape.xplr**][19] Material Landscape
- [**material-landscape2.xplr**][20] Material Landscape 2
- [**zentable.xplr**][31] A clean, distraction free xplr table UI
- [**icons.xplr**][30] An icon theme for xplr.


[1]:./writing-plugins.md
[2]:#integration
[3]:#theme
[4]:https://github.com/sayanarijit/dragon.xplr
[5]:https://github.com/mwh/dragon
[6]:https://github.com/sayanarijit/dua-cli.xplr
[7]:https://github.com/Byron/dua-cli
[8]:https://github.com/sayanarijit/fzf.xplr
[9]:https://github.com/junegunn/fzf
[10]:https://github.com/sayanarijit/preview-tabbed.xplr
[11]:https://tools.suckless.org/tabbed/
[12]:https://github.com/jarun/nnn/blob/master/plugins/preview-tabbed
[13]:https://github.com/sayanarijit/trash-cli.xplr
[14]:https://github.com/andreafrancia/trash-cli
[15]:https://github.com/sayanarijit/xclip.xplr
[16]:https://github.com/astrand/xclip
[17]:https://github.com/sayanarijit/zoxide.xplr
[18]:https://github.com/ajeetdsouza/zoxide
[19]:https://github.com/sayanarijit/material-landscape.xplr
[20]:https://github.com/sayanarijit/material-landscape2.xplr
[21]:https://github.com/sayanarijit/comex.xplr
[22]:https://github.com/sayanarijit/xargs.xplr
[23]:https://github.com/dtomvan/paste-rs.xplr
[24]:https://paste.rs
[25]:https://github.com/sayanarijit/completion.xplr
[26]:https://github.com/sayanarijit/qrcp.xplr
[27]:https://github.com/claudiodangelis/qrcp
[28]:https://github.com/prncss-xyz/type-to-nav.xplr
[29]:https://github.com/jarun/nnn/wiki/concepts#type-to-nav
[30]:https://github.com/prncss-xyz/icons.xplr
[31]:https://github.com/sayanarijit/zentable.xplr
[32]:#extension
[33]:https://github.com/sayanarijit/alacritty.xplr
[34]:https://github.com/alacritty/alacritty
